@@ -848,8 +848,9 @@ ggbrain_layer <- R6::R6Class(
 #' @param object the ggbrain_layer object to be added to an existing ggplot
 #' @param plot the ggplot object
 #' @param object_name not used, but required by ggplot_add
+#' @param ... additional arguments, not currently used
 #' @importFrom ggplot2 ggplot_add
 #' @export
-ggplot_add.ggbrain_layer <- function(object, plot, object_name) {
+ggplot_add.ggbrain_layer <- function(object, plot, object_name, ...) {
   object$add_to_gg(plot) # adds the layer to the extant plot
 }
